@@ -3,14 +3,14 @@
 import logging as _logging
 
 from . import types
-from ._helpers import read_todos_from_file
+from ._group import TodoGroup
 from ._todo import DEFAULT_PRIORITY, Todo
 
 
-__all__ = ["DEFAULT_PRIORITY", "Todo", "read_todos_from_file", "types"]
+__all__ = ["DEFAULT_PRIORITY", "Todo", "TodoGroup", "types"]
 
 __author__ = "Bryan M Bugyi"
 __email__ = "bryanbugyi34@gmail.com"
-__version__ = "0.2.0"
+__version__ = "0.3.1"
 
 _logging.getLogger(__name__).addHandler(_logging.NullHandler())
