@@ -2,9 +2,11 @@
 
 from __future__ import annotations
 
-from typing import Literal
+from typing import Dict, List, Literal, Union
 
 
+# Type of the Todo.metadata attribute.
+Metadata = Dict[str, Union[str, List[str]]]
 # A todo item's priority is always a capital letter.
 Priority = Literal[
     "A",
