@@ -1,7 +1,9 @@
 """The catch-all module for the tests.data package."""
 
 from pathlib import Path
-from typing import List
+from typing import List, cast
+
+from pytest import param
 
 
 def get_all_todo_files() -> List[Path]:
@@ -10,7 +12,11 @@ def get_all_todo_files() -> List[Path]:
 
     result = []
 
-    for txt in todo_dir_path.glob("*.txt"):
-        result.append(txt)
+    for txt_or_dir in todo_dir_path.glob("*"):
+        if txt_or_dir.is_file() and txt_or_dir.suffix != ".txt":
+            continue
+
+        P = cast(Path, param(txt_or_dir, id=txt_or_dir.stem))
+        result.append(P)
 
     return result
